<?php

return [
    'number.decimals_separator' => ',',
    'number.thousands_separator' => ' ',
    'None' => 'Žiadne',
    'Edit' => 'Upraviť',
    'Remove' => 'Odstrániť',
    'Yes' => 'Áno',
    'No' => 'Nie',
    'cancel' => 'zrušiť',
    'or' => 'alebo',
    'Yellow' => 'Žltá',
    'Blue' => 'Modrá',
    'Green' => 'Zelená',
    'Purple' => 'Fialová',
    'Red' => 'Červená',
    'Orange' => 'Oranžová',
    'Grey' => 'Sivá',
    'Brown' => 'Hnedá',
    'Deep Orange' => 'Sýto oranžová',
    'Dark Grey' => 'Tmavo sivá',
    'Pink' => 'Ružová',
    'Teal' => 'Modro zelená',
    'Cyan' => 'Azúrová',
    'Lime' => 'Limetková',
    'Light Green' => 'Svetlo zelená',
    'Amber' => 'Jantárová',
    'Save' => 'Uložiť',
    'Login' => 'Prihlásiť',
    'Official website:' => 'Oficiálna stránka:',
    'Unassigned' => 'Nepridelené',
    'View this task' => 'Zobraziť túto úlohu',
    'Remove user' => 'Odstrániť používateľa',
    'Do you really want to remove this user: "%s"?' => 'Naozaj chcete odstrániť používateľa: „%s”?',
    'All users' => 'Všetci používatelia',
    'Username' => 'Prihlasovacie meno',
    'Password' => 'Heslo',
    'Administrator' => 'Administrátor',
    'Sign in' => 'Prihlásiť sa',
    'Users' => 'Používatelia',
    'Forbidden' => 'Zakázané',
    'Access Forbidden' => 'Prístup zakázaný',
    'Edit user' => 'Upraviť používateľa',
    'Logout' => 'Odhlásiť',
    'Bad username or password' => 'Zlé používateľské meno alebo heslo',
    'Edit project' => 'Upraviť projekt',
    'Name' => 'Meno',
    'Projects' => 'Projekty',
    'No project' => 'Žiadne projekty',
    'Project' => 'Projekt',
    'Status' => 'Stav',
    'Tasks' => 'Úlohy',
    'Board' => 'Nástenka',
    'Actions' => 'Akcie',
    'Inactive' => 'Neaktívne',
    'Active' => 'Aktívne',
    'Unable to update this board.' => 'Nemožno aktualizovať nástenku.',
    'Disable' => 'Zakázať',
    'Enable' => 'Zapnúť',
    'New project' => 'Nový projekt',
    'Do you really want to remove this project: "%s"?' => 'Naozaj chcete odstrániť projekt: „%s”?',
    'Remove project' => 'Odstrániť projekt',
    'Edit the board for "%s"' => 'Upraviť nástenku „%s”',
    'Add a new column' => 'Pridať nový stĺpec',
    'Title' => 'Názov',
    'Assigned to %s' => 'Pridelené používateľovi %s',
    'Remove a column' => 'Odstrániť stĺpec',
    'Unable to remove this column.' => 'Nemožno odstrániť tento stĺpec.',
    'Do you really want to remove this column: "%s"?' => 'Naozaj chcete odstrániť stĺpec „%s”?',
    'Settings' => 'Nastavenia',
    'Application settings' => 'Nastavenia aplikácie',
    'Language' => 'Jazyk',
    'Webhook token:' => 'Token webového háku:',
    'API token:' => 'Token API:',
    'Database size:' => 'Veľkosť databázy:',
    'Download the database' => 'Stiahnuť databázu',
    'Optimize the database' => 'Optimalizovať databázu',
    '(VACUUM command)' => '(príkaz VACUUM)',
    '(Gzip compressed Sqlite file)' => 'Súbor SQLite, komprimovaný gzip)',
    'Close a task' => 'Ukončiť úlohu',
    'Column' => 'Stĺpec',
    'Color' => 'Farba',
    'Assignee' => 'Pridelené',
    'Create another task' => 'Vytvoriť ďalšiu úlohu',
    'New task' => 'Nová úloha',
    'Open a task' => 'Otvoriť úlohu',
    'Do you really want to open this task: "%s"?' => 'Naozaj chcete otvoriť úlohu: „%s”?',
    'Back to the board' => 'Späť na nástenku',
    'There is nobody assigned' => 'Nie je pridelené nikomu',
    'Column on the board:' => 'Stĺpec nástenky:',
    'Close this task' => 'Ukončiť túto úlohu',
    'Open this task' => 'Otvoriť túto úlohu',
    'There is no description.' => 'Nemá popis.',
    'Add a new task' => 'Pridať novú úlohu',
    'The username is required' => 'Prihl. meno je povinné',
    'The maximum length is %d characters' => 'Maximálna dĺžka je %d znakov',
    'The minimum length is %d characters' => 'Minimálna dĺžka je %d znakov',
    'The password is required' => 'Heslo je povinné',
    'This value must be an integer' => 'Táto hodnota musí byť celé číslo',
    'The username must be unique' => 'Prihl. meno musí byť jedinečné',
    'The user id is required' => 'ID používateľa je povinné',
    'Passwords don\'t match' => 'Heslá sa nezhodujú',
    'The confirmation is required' => 'Potvrdenie je povinné',
    'The project is required' => 'Projekt je povinný',
    'The id is required' => 'ID je povinné',
    'The project id is required' => 'ID projektu je povinné',
    'The project name is required' => 'Meno projektu je povinné',
    'The title is required' => 'Názov je povinný',
    'Settings saved successfully.' => 'Nastavenia úspešne uložené.',
    'Unable to save your settings.' => 'Nemožno uložiť nastavenia.',
    'Database optimization done.' => 'Optimalizácia databázy dokončená.',
    'Your project has been created successfully.' => 'Projekt úspešne vytvorený.',
    'Unable to create your project.' => 'Nemožno vytvoriť projekt.',
    'Project updated successfully.' => 'Projekt úspešne aktualizovaný.',
    'Unable to update this project.' => 'Nemožno aktualizovať projekt.',
    'Unable to remove this project.' => 'Nemožno odstrániť projekt.',
    'Project removed successfully.' => 'Projekt úspešne odstránený.',
    'Project activated successfully.' => 'Projekt úspešne aktivovaný.',
    'Unable to activate this project.' => 'Nemožno aktivovať projekt.',
    'Project disabled successfully.' => 'Projekt úspešne vypnutý.',
    'Unable to disable this project.' => 'Nemožno vypnúť projekt.',
    'Unable to open this task.' => 'Nemožno otvoriť úlohu.',
    'Task opened successfully.' => 'Úloha úspešne otvorená.',
    'Unable to close this task.' => 'Nemožno ukončiť túto úlohu.',
    'Task closed successfully.' => 'Úloha úspešne ukončená.',
    'Unable to update your task.' => 'Nemožno aktualizovať úlohu.',
    'Task updated successfully.' => 'Úloha úspešne aktualizovaná.',
    'Unable to create your task.' => 'Nemožno vytvoriť úlohu.',
    'Task created successfully.' => 'Úloha úspešne vytvorená.',
    'User created successfully.' => 'Používateľ úspešne vytvorený.',
    'Unable to create your user.' => 'Nemožno vytvoriť používateľa.',
    'User updated successfully.' => 'Používateľ úspešne aktualizovaný.',
    'User removed successfully.' => 'Používateľ úspešne odstránený.',
    'Unable to remove this user.' => 'Nemožno odstrániť používateľa.',
    'Board updated successfully.' => 'Nástenka úspešne aktualizovaná.',
    'Ready' => 'Pripravené',
    'Backlog' => 'Nevybavené',
    'Work in progress' => 'V riešení',
    'Done' => 'Dokončené',
    'Application version:' => 'Verzia aplikácie:',
    'Id' => 'ID',
    'Public link' => 'Verejný odkaz',
    'Timezone' => 'Časové pásmo',
    'Sorry, I didn\'t find this information in my database!' => 'Prepáčte, túto informáciu som v databáze nenašiel!',
    'Page not found' => 'Stránka neexistuje',
    'Complexity' => 'Zložitosť',
    'Task limit' => 'Limit úloh',
    'Task count' => 'Počet úloh',
    'User' => 'Používateľ',
    'Comments' => 'Komentáre',
    'Comment is required' => 'Komentár je povinný',
    'Comment added successfully.' => 'Komentár úspešne pridaný.',
    'Unable to create your comment.' => 'Nemožno vytvoriť komentár.',
    'Due Date' => 'Dátum splnenia',
    'Invalid date' => 'Neplatný dátum',
    'Automatic actions' => 'Automatické akcie',
    'Your automatic action has been created successfully.' => 'Automatická akcia úspešne vytvorená.',
    'Unable to create your automatic action.' => 'Nemožno vytvoriť automatickú akciu.',
    'Remove an action' => 'Odstrániť akciu',
    'Unable to remove this action.' => 'Nemožno odstrániť akciu.',
    'Action removed successfully.' => 'Akcia úspešne odstránená.',
    'Automatic actions for the project "%s"' => 'Automatické akcie projektu „%s”',
    'Add an action' => 'Pridať akciu',
    'Event name' => 'Názov udalosti',
    'Action' => 'Akcia',
    'Event' => 'Udalosť',
    'When the selected event occurs execute the corresponding action.' => 'Keď nastane zvolená udalosť, vykonať príslušnú akciu.',
    'Next step' => 'Ďalší krok',
    'Define action parameters' => 'Definujte parametre akcie',
    'Do you really want to remove this action: "%s"?' => 'Naozaj chcete odstrániť akciu: „%s”?',
    'Remove an automatic action' => 'Odstrániť automatickú akciu',
    'Assign the task to a specific user' => 'Prideliť úlohu zadanému používateľovi',
    'Assign the task to the person who does the action' => 'Prideliť úlohu osobe, ktorá vykonala akciu',
    'Duplicate the task to another project' => 'Duplikovať akciu do iného projektu',
    'Move a task to another column' => 'Presun úlohy do iného stĺpca',
    'Task modification' => 'Úprava úlohy',
    'Task creation' => 'Vytvorenie úlohy',
    'Closing a task' => 'Ukončenie úlohy',
    'Assign a color to a specific user' => 'Priradiť farbu zadanému používateľovi',
    'Position' => 'Pozícia',
    'Duplicate to project' => 'Duplikovať do iného projektu',
    'Duplicate' => 'Duplikovať',
    'Link' => 'Odkaz',
    'Comment updated successfully.' => 'Komentár úspešne aktualizovaný.',
    'Unable to update your comment.' => 'Nemožno aktualizovať komentár.',
    'Remove a comment' => 'Odstrániť komentár',
    'Comment removed successfully.' => 'Komentár úspešne odstránený.',
    'Unable to remove this comment.' => 'Nemožno odstrániť tento  komentár.',
    'Do you really want to remove this comment?' => 'Naozaj chcete odstrániť tento komentár?',
    'Current password for the user "%s"' => 'Aktuálne heslo používateľa „%s”',
    'The current password is required' => 'Aktuálne heslo je povinné',
    'Wrong password' => 'Zlé heslo',
    'Unknown' => 'Neznáme',
    'Last logins' => 'Posledné prihlásenia',
    'Login date' => 'Dátum prihlásenia',
    'Authentication method' => 'Metóda autentifikácie',
    'IP address' => 'Adresa IP',
    'User agent' => 'User-Agent',
    'Persistent connections' => 'Trvalé spojenia',
    'No session.' => 'Bez relácie.',
    'Expiration date' => 'Dátum platnosti',
    'Remember Me' => 'Zapamätať si ma',
    'Creation date' => 'Dátum vytvorenia',
    'Everybody' => 'Každý',
    'Open' => 'Otvorené',
    'Closed' => 'Ukončené',
    'Search' => 'Hľadať',
    'Nothing found.' => 'Nič nenájdené.',
    'Due date' => 'Termín splnenia',
    'Description' => 'Popis',
    '%d comments' => '%d komentáre(ov)',
    '%d comment' => '%d komentár',
    'Email address invalid' => 'Neplatná emailová adresa',
    'Your external account is not linked anymore to your profile.' => 'Externý účet už nie je prepojený s Vašim profilom.',
    'Unable to unlink your external account.' => 'Nemožno zrušiť prepojenie s externým účtom.',
    'External authentication failed' => 'Externá autentifikácia zlyhala',
    'Your external account is linked to your profile successfully.' => 'Externý účet úspešne prepojený s profilom.',
    'Email' => 'Email',
    'Task removed successfully.' => 'Úloha úspešne odstránená.',
    'Unable to remove this task.' => 'Nemožno odstrániť úlohu.',
    'Remove a task' => 'Odstrániť úlohu',
    'Do you really want to remove this task: "%s"?' => 'Naozaj chcete odstrániť úlohu: „%s”?',
    'Assign automatically a color based on a category' => 'Automaticky nastaviť farbu na základe kategórie',
    'Assign automatically a category based on a color' => 'Automaticky nastaviť kategóriu na základe farby',
    'Task creation or modification' => 'Vytvorenie alebo úprava úlohy',
    'Category' => 'Kategória',
    'Category:' => 'Kategória:',
    'Categories' => 'Kategórie',
    'Your category has been created successfully.' => 'Kategória úspešne vytvorená.',
    'This category has been updated successfully.' => 'Kategória úspešne aktualizovaná.',
    'Unable to update this category.' => 'Nemožno aktualizovať kategóriu.',
    'Remove a category' => 'Odstrániť kategóriu',
    'Category removed successfully.' => 'Kategória úspešne odstránená.',
    'Unable to remove this category.' => 'Nemožno odstrániť kategóriu.',
    'Category modification for the project "%s"' => 'Úprava kategórie projektu „%s”',
    'Category Name' => 'Meno kategórie',
    'Add a new category' => 'Pridať novú kategóriu',
    'Do you really want to remove this category: "%s"?' => 'Naozaj chcete odstrániť kategóriu: „%s”?',
    'All categories' => 'Všetky kategórie',
    'No category' => 'Bez kategórie',
    'The name is required' => 'Meno je povinné',
    'Remove a file' => 'Odstrániť súbor',
    'Unable to remove this file.' => 'Nemožno odstrániť súbor.',
    'File removed successfully.' => 'Súbor úspešne odstránený.',
    'Attach a document' => 'Pripojiť dokument',
    'Do you really want to remove this file: "%s"?' => 'Naozaj chcete odstrániť súbor: „%s”?',
    'Attachments' => 'Prílohy',
    'Edit the task' => 'Upraviť úlohu',
    'Add a comment' => 'Pridať komentár',
    'Edit a comment' => 'Upraviť komentár',
    'Summary' => 'Zhrnutie',
    'Time tracking' => 'Sledovanie času',
    'Estimate:' => 'Očakávané:',
    'Spent:' => 'Strávené:',
    'Do you really want to remove this sub-task?' => 'Naozaj chcete odstrániť túto podúlohu?',
    'Remaining:' => 'Ostáva:',
    'hours' => 'hodiny',
    'estimated' => 'očakávané',
    'Sub-Tasks' => 'Podúlohy',
    'Add a sub-task' => 'Pridať podúlohu',
    'Original estimate' => 'Predpokladaný čas',
    'Create another sub-task' => 'Vytvoriť ďalšiu podúlohu',
    'Time spent' => 'Strávený čas',
    'Edit a sub-task' => 'Upraviť podúlohu',
    'Remove a sub-task' => 'Odstrániť podúlohu',
    'The time must be a numeric value' => 'Čas musí byť číselná hodnota',
    'Todo' => 'Čaká',
    'In progress' => 'V riešení',
    'Sub-task removed successfully.' => 'Podúloha úspešne odstránená.',
    'Unable to remove this sub-task.' => 'Nemožno odstrániť podúlohu.',
    'Sub-task updated successfully.' => 'Podúloha úspešne aktualizovaná.',
    'Unable to update your sub-task.' => 'Nemožno aktualizovať podúlohu.',
    'Unable to create your sub-task.' => 'Nemožno vytvoriť podúlohu.',
    'Maximum size: ' => 'Maximálna veľkosť: ',
    'Display another project' => 'Zobraziť iný projekt',
    'Created by %s' => 'Vytvoril %s',
    'Tasks Export' => 'Export úloh',
    'Start Date' => 'Dátum začiatku',
    'Execute' => 'Vykonať',
    'Task Id' => 'ID úlohy',
    'Creator' => 'Vytvoril',
    'Modification date' => 'Dátum úpravy',
    'Completion date' => 'Dátum ukončenia',
    'Clone' => 'Naklonovať',
    'Project cloned successfully.' => 'Projekt úspešne naklonovaný.',
    'Unable to clone this project.' => 'Nemožno naklonovať tento projekt.',
    'Enable email notifications' => 'Zapnúť upozornenia emailom',
    'Task position:' => 'Pozícia úlohy:',
    'The task #%d has been opened.' => 'Úloha #%d bola otvorená.',
    'The task #%d has been closed.' => 'Úloha #%d bola ukončená.',
    'Sub-task updated' => 'Podúloha aktualizovaná',
    'Title:' => 'Názov:',
    'Status:' => 'Stav:',
    'Assignee:' => 'Pridelené:',
    'Time tracking:' => 'Sledovanie času:',
    'New sub-task' => 'Nová podúloha',
    'New attachment added "%s"' => 'Nová príloha pridaná %s',
    'New comment posted by %s' => 'Nový komentár poslaný %s',
    'New comment' => 'Nový komentár',
    'Comment updated' => 'Komentár aktualizovaný',
    'New subtask' => 'Nová podúloha',
    'I only want to receive notifications for these projects:' => 'Chcem dostávať upozornenia len z týchto projektov:',
    'view the task on Kanboard' => 'zobraziť úlohu v Kanboard',
    'Public access' => 'Verejný prístup',
    'Disable public access' => 'Zakázať verejný prístup',
    'Enable public access' => 'Zapnúť verejný prístup',
    'Public access disabled' => 'Verejný prístup zakázaný',
    'Move the task to another project' => 'Presunúť úlohu do iného projektu',
    'Move to project' => 'Presunúť do projektu',
    'Do you really want to duplicate this task?' => 'Naozaj chcete duplikovať túto úlohu?',
    'Duplicate a task' => 'Duplikovať úlohu',
    'External accounts' => 'Externé účty',
    'Account type' => 'Typ účtu',
    'Local' => 'Lokálny',
    'Remote' => 'Vzdialený',
    'Enabled' => 'Vypnuté',
    'Disabled' => 'Zapnuté',
    'Login:' => 'Prihl. meno:',
    'Full Name:' => 'Celé meno:',
    'Email:' => 'Email:',
    'Notifications:' => 'Upozornenia:',
    'Notifications' => 'Upozornenia',
    'Account type:' => 'Typ účtu:',
    'Edit profile' => 'Upraviť profil',
    'Change password' => 'Zmeniť heslo',
    'Password modification' => 'Úprava hesla',
    'External authentications' => 'Externé autentifikácie',
    'Never connected.' => 'Nikdy neprihlásený.',
    'No external authentication enabled.' => 'Žiadne povolené externé autentifikácie.',
    'Password modified successfully.' => 'Heslo úspešne zmenené.',
    'Unable to change the password.' => 'Nemožno zmeniť heslo.',
    'Change category' => 'Zmeniť kategóriu',
    '%s updated the task %s' => '%s upravil úlohu %s',
    '%s opened the task %s' => '%s otvoril úlohu %s',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s presunul úlohu %s na pozíciu #%d v stĺpci „%s”',
    '%s moved the task %s to the column "%s"' => '%s presunul úlohu %s do stĺpca „%s”',
    '%s created the task %s' => '%s vytvoril úlohu %s',
    '%s closed the task %s' => '%s ukončil úlohu %s',
    '%s created a subtask for the task %s' => '%s vytvoril podúlohu úlohy %s',
    '%s updated a subtask for the task %s' => '%s upravil podúlohu úlohy %s',
    'Assigned to %s with an estimate of %s/%sh' => 'Pridelené %s s očakávaním %s/%s h',
    'Not assigned, estimate of %sh' => 'Nepridelené, očakávané %s h',
    '%s updated a comment on the task %s' => '%s aktualizoval komentár úlohy %s',
    '%s commented the task %s' => '%s komentoval úlohu %s',
    '%s\'s activity' => 'Aktivita používateľa %s',
    'RSS feed' => 'Kanál RSS',
    '%s updated a comment on the task #%d' => '%s upravil komentár úlohy #%d',
    '%s commented on the task #%d' => '%s pridal komentár úlohy #%d',
    '%s updated a subtask for the task #%d' => '%s upravil podúlohu úlohy #%d',
    '%s created a subtask for the task #%d' => '%s vytvoril podúlohu úlohy #%d',
    '%s updated the task #%d' => '%s upravil úlohu #%d',
    '%s created the task #%d' => '%s vytvoril úlohu #%d',
    '%s closed the task #%d' => '%s ukončil úlohu #%d',
    '%s opened the task #%d' => '%s otvoril úlohu #%d',
    'Activity' => 'Aktivita',
    'Default values are "%s"' => 'Predvolené hodnoty sú „%s”',
    'Default columns for new projects (Comma-separated)' => 'Predvolené stĺpce nových projektov (oddelené čiarkami)',
    'Task assignee change' => 'Zmena pridelenia úlohy',
    '%s changed the assignee of the task #%d to %s' => '%s zmenil pridelenie úlohy #%d na %s',
    '%s changed the assignee of the task %s to %s' => '%s zmenil pridelenie úlohy %s na %s',
    'New password for the user "%s"' => 'Nové heslo používateľa „%s”',
    'Choose an event' => 'Zvoľte udalosť',
    'Create a task from an external provider' => 'Vytvoriť úlohu od externého poskytovateľa',
    'Change the assignee based on an external username' => 'Zmeniť pridelenie na základe externého používateľa',
    'Change the category based on an external label' => 'Zmeniť kategóriu na základe externej menovky',
    'Reference' => 'Odkaz',
    'Label' => 'Menovka',
    'Database' => 'Databázy',
    'About' => 'O aplikácii',
    'Database driver:' => 'Ovládač databázy:',
    'Board settings' => 'Nastavenia nástenky',
    'Webhook settings' => 'Nastavenia webových hákov',
    'Reset token' => 'Obnoviť token',
    'API endpoint:' => 'Prípojný bod API:',
    'Refresh interval for personal board' => 'Interval obnovenia súkromných násteniek',
    'Refresh interval for public board' => 'Interval obnovenia verejných násteniek',
    'Task highlight period' => 'Doba zvýraznenia úlohy',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Doba (v sekundách), počas ktorej považovať úlohu za nedávno upravenú (0 na vypnutie, predvolene 2 dni)',
    'Frequency in second (60 seconds by default)' => 'Frekvencia v sekundách (predvolene 60 sekúnd)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Frekvencia v sekundách (predvolene 10 sekúnd)',
    'Application URL' => 'URL aplikácie',
    'Token regenerated.' => 'Token obnovený.',
    'Date format' => 'Formát dátumu',
    'ISO format is always accepted, example: "%s" and "%s"' => 'Formát ISO je vždy prijímaný, napr.: „%s” a %s”',
    'New personal project' => 'Nový súkromný projekt',
    'This project is personal' => 'Tento projekt je súkromný',
    'Add' => 'Pridať',
    'Start date' => 'Dátum začiatku',
    'Time estimated' => 'Očakávaný čas',
    'There is nothing assigned to you.' => 'Nemáte nič pridelené.',
    'My tasks' => 'Moje úlohy',
    'Activity stream' => 'Prehľad aktivity',
    'Dashboard' => 'Nástenka',
    'Confirmation' => 'Potvrdenie',
    'Webhooks' => 'Webové háky',
    'API' => 'API',
    'Create a comment from an external provider' => 'Vytvoriť komentár od externého poskytovateľa',
    'Project management' => 'Správa projektov',
    'Columns' => 'Stĺpce',
    'Task' => 'Úloha',
    'Percentage' => 'Percentá',
    'Number of tasks' => 'Počet úloh',
    'Task distribution' => 'Distribúcia úloh',
    'Analytics' => 'Analytika',
    'Subtask' => 'Podúloha',
    'User repartition' => 'Rozdelenie používateľov',
    'Clone this project' => 'Naklonovať tento projekt',
    'Column removed successfully.' => 'Stĺpec úspešne odstránený.',
    'Not enough data to show the graph.' => 'Nedostatok dát na zobrazenie grafu.',
    'Previous' => 'Predošlé',
    'The id must be an integer' => 'ID musí byť celé číslo',
    'The project id must be an integer' => 'ID projektu musí byť celé číslo',
    'The status must be an integer' => 'Stav musí byť celé číslo',
    'The subtask id is required' => 'ID podúlohy je povinné',
    'The subtask id must be an integer' => 'ID podúlohy musí byť celé číslo',
    'The task id is required' => 'ID úlohy je povinné',
    'The task id must be an integer' => 'ID úlohy musí byť celé číslo',
    'The user id must be an integer' => 'ID používateľa musí byť celé číslo',
    'This value is required' => 'Táto hodnota je povinná',
    'This value must be numeric' => 'Táto hodnota musí byť číselná',
    'Unable to create this task.' => 'Nemožno vytvoriť túto úlohu.',
    'Cumulative flow diagram' => 'Kumulatívny diagram toku',
    'Daily project summary' => 'Senný sumár projektu',
    'Daily project summary export' => 'Export denného sumáru projektu',
    'Exports' => 'Exporty',
    'This export contains the number of tasks per column grouped per day.' => 'Tento export obsahuje počet úloh na stĺpec, zoskupené pod dňoch.',
    'Active swimlanes' => 'Aktívne dráhy',
    'Add a new swimlane' => 'Pridať novú dráhu',
    'Default swimlane' => 'Hlavná dráha',
    'Do you really want to remove this swimlane: "%s"?' => 'Naozaj chcete odstrániť dráhu: „%s”?',
    'Inactive swimlanes' => 'Neaktívne dráhy',
    'Remove a swimlane' => 'Odstrániť dráhu',
    'Swimlane modification for the project "%s"' => 'Úpravy dráhy projektu „%s”',
    'Swimlane removed successfully.' => 'Dráha úspešne odstránená.',
    'Swimlanes' => 'Dráhy',
    'Swimlane updated successfully.' => 'Dráha úspešne upravená.',
    'Unable to remove this swimlane.' => 'Nemožno odstrániť túto dráhu.',
    'Unable to update this swimlane.' => 'Nemožno upraviť túto dráhu.',
    'Your swimlane has been created successfully.' => 'Dráha úspešne vytvorená.',
    'Example: "Bug, Feature Request, Improvement"' => 'Príklad: "Chyba, Nová vlastnosť, Vylepšenie"',
    'Default categories for new projects (Comma-separated)' => 'Predvolené kategórie nových projektov (oddelené čiarkami)',
    'Integrations' => 'Integrácie',
    'Integration with third-party services' => 'Integrácia so službami tretích strán',
    'Subtask Id' => 'ID podúlohy',
    'Subtasks' => 'Podúlohy',
    'Subtasks Export' => 'Export podúloh',
    'Task Title' => 'Názov úlohy',
    'Untitled' => 'Bez názvu',
    'Application default' => 'Predvolené',
    'Language:' => 'Jazyk:',
    'Timezone:' => 'Časové pásmo:',
    'All columns' => 'Všetky stĺpce',
    'Next' => 'Ďalšie',
    '#%d' => '# %d',
    'All swimlanes' => 'Všetky dráhy',
    'All colors' => 'Všetky farby',
    'Moved to column %s' => 'Presunuté do stĺpca %s',
    'User dashboard' => 'Nástenka používateľa',
    'Allow only one subtask in progress at the same time for a user' => 'Povoliť len jednu spracovávanú podúlohu v rovnakom čase na používateľa',
    'Edit column "%s"' => 'Upraviť stĺpec „%s”',
    'Select the new status of the subtask: "%s"' => 'Vyberte nový stav podúlohy: „%s”',
    'Subtask timesheet' => 'Výkaz podúloh',
    'There is nothing to show.' => 'Nič na zobrazenie.',
    'Time Tracking' => 'Sledovanie času',
    'You already have one subtask in progress' => 'Už máte jednu podúlohu v riešení',
    'Which parts of the project do you want to duplicate?' => 'Ktoré časti projektu chcete duplikovať?',
    'Disallow login form' => 'Zakázať prihlasovací formulár',
    'Start' => 'Začiatok',
    'End' => 'Koniec',
    'Task age in days' => 'Vek úlohy v dňoch',
    'Days in this column' => 'Dní v tomto stĺpci',
    '%dd' => '%d d',
    'Add a new link' => 'Pridať nový odkaz',
    'Do you really want to remove this link: "%s"?' => 'Naozaj chcete odstrániť odkaz: „%s”?',
    'Do you really want to remove this link with task #%d?' => 'Naozaj chcete odstrániť odkaz s úlohou #%d?',
    'Field required' => 'Pole je povinné',
    'Link added successfully.' => 'Odkaz úspešne pridaný.',
    'Link updated successfully.' => 'Odkaz úspešne upravený.',
    'Link removed successfully.' => 'Odkaz úspešne odstránený.',
    'Link labels' => 'Menovky odkazov',
    'Link modification' => 'Úprava odkazu',
    'Opposite label' => 'Opačná menovka',
    'Remove a link' => 'Odstrániť odkaz',
    'The labels must be different' => 'Menovky sa musia líšiť',
    'There is no link.' => 'Žiadny odkaz.',
    'This label must be unique' => 'Menovka musí byť jedinečná',
    'Unable to create your link.' => 'Nemožno vytvoriť odkaz.',
    'Unable to update your link.' => 'Nemožno aktualizovať odkaz.',
    'Unable to remove this link.' => 'Nemožno odstrániť odkaz.',
    'relates to' => 'súvisí s',
    'blocks' => 'blokuje',
    'is blocked by' => 'je blokovaná',
    'duplicates' => 'duplikuje',
    'is duplicated by' => 'je duplikovaná',
    'is a child of' => 'je potomkom',
    'is a parent of' => 'je rodičom',
    'targets milestone' => 'cieľový míľnik',
    'is a milestone of' => 'je míľnikom',
    'fixes' => 'opravuje',
    'is fixed by' => 'je opravená',
    'This task' => 'Táto úloha',
    '<1h' => '<1 h',
    '%dh' => '%d h',
    'Expand tasks' => 'Rozbaliť úlohy',
    'Collapse tasks' => 'Zbaliť úlohy',
    'Expand/collapse tasks' => 'Rozbaliť/Zbaliť úlohy',
    'Close dialog box' => 'Zatvoriť dialógové okno',
    'Submit a form' => 'Odoslať formulár',
    'Board view' => 'Zobrazenie nástenky',
    'Keyboard shortcuts' => 'Klávesové skratky',
    'Open board switcher' => 'Prepínač otvorených násteniek',
    'Application' => 'Aplikácia',
    'Compact view' => 'Kompaktné zobrazenie',
    'Horizontal scrolling' => 'Vodorovný posun',
    'Compact/wide view' => 'Kompaktné/široké zobrazenie',
    'Currency' => 'Mena',
    'Personal project' => 'Súkromný projekt',
    'AUD - Australian Dollar' => 'AUD – Austrálsky dolár',
    'CAD - Canadian Dollar' => 'CAD – Kanadský dolár',
    'CHF - Swiss Francs' => 'CHF – Švajčiarsky frank',
    'Custom Stylesheet' => 'Vlastné CSS',
    'EUR - Euro' => 'EUR – Euro',
    'GBP - British Pound' => 'GBP – Britská libra',
    'INR - Indian Rupee' => 'INR – Indická rupia',
    'JPY - Japanese Yen' => 'JPY – Japonský jen',
    'NZD - New Zealand Dollar' => 'NZD – Novozélandský dolár',
    'PEN - Peruvian Sol' => 'PEN – peruánsky sol',
    'RSD - Serbian dinar' => 'RSD – Srbský dinár',
    'CNY - Chinese Yuan' => 'CNY – Čínsky juan',
    'USD - US Dollar' => 'USD – Americký dolár',
    'VES - Venezuelan Bolívar' => 'Venezuelský bolívar',
    'Destination column' => 'Cieľový stĺpec',
    'Move the task to another column when assigned to a user' => 'Presunúť úlohu do iného stĺpca, keď je pridelená používateľovi',
    'Move the task to another column when assignee is cleared' => 'Presunúť úlohu do iného stĺpca, keď je pridelenie vymazané',
    'Source column' => 'Zdrojový stĺpec',
    'Transitions' => 'Prechody',
    'Executer' => 'Spúšťač',
    'Time spent in the column' => 'Čas strávený v stĺpci',
    'Task transitions' => 'Prechody úloh',
    'Task transitions export' => 'Export prechodov úloh',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Tento výstup obsahuje presuny stĺpcov všetkých úloh s dátumom, používateľom a časom stráveným v každom prechode.',
    'Currency rates' => 'Kurzy meny',
    'Rate' => 'Kurz',
    'Change reference currency' => 'Zmeniť referenčnú menu',
    'Reference currency' => 'Referenčná mena',
    'The currency rate has been added successfully.' => 'Kurz meny bol úspešne pridaný.',
    'Unable to add this currency rate.' => 'Nemožno pridať tento kurz meny.',
    'Webhook URL' => 'URL webového háku',
    '%s removed the assignee of the task %s' => '%s odstránil pridelenie úlohy %s',
    'Information' => 'Informácie',
    'Check two factor authentication code' => 'Overiť dvojfaktorový autentifikačný kód',
    'The two factor authentication code is not valid.' => 'Dvojfaktorový autentifikačný kód nie je platný.',
    'The two factor authentication code is valid.' => 'Dvojfaktorový autentifikačný kód je platný.',
    'Code' => 'Kód',
    'Two factor authentication' => 'Dvojfaktorová autentifikácia',
    'This QR code contains the key URI: ' => 'Tento kód QR obsahuje URI kľúča: ',
    'Check my code' => 'Skontrolovať svoj kód',
    'Secret key: ' => 'Tajný kľúč: ',
    'Test your device' => 'Otestujte svoje zariadenie',
    'Assign a color when the task is moved to a specific column' => 'Nastaviť farbu, keď je úloha presunutá do zadaného stĺpca',
    '%s via Kanboard' => '%s cez Kanboard',
    'Burndown chart' => 'Burndown diagram',
    'This chart show the task complexity over the time (Work Remaining).' => 'Tento diagram zobrazuje komplexnosť úloh v čase (Zostávajúca práca).',
    'Screenshot taken %s' => 'Vytvorená snímka obrazovky %s',
    'Add a screenshot' => 'Pridať snímku obrazovky',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Vytvorte snímku obrazovky a stlačte CTRL+V alebo ⌘+V na jej vloženie tu.',
    'Screenshot uploaded successfully.' => 'Snímka úspešne nahraná.',
    'SEK - Swedish Krona' => 'SEK – Švédska koruna',
    'Identifier' => 'Identifikátor',
    'Disable two factor authentication' => 'Vypnúť dvojfaktorovú autentifikáciu',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => 'Naozaj chcete zakázať dvojfaktorovú autentifikáciu používateľa: „%s”?',
    'Edit link' => 'Upraviť odkaz',
    'Start to type task title...' => 'Začnite písať názov úlohy...',
    'A task cannot be linked to itself' => 'Úloha nemôže odkazovať sama na seba',
    'The exact same link already exists' => 'Rovnaký odkaz už existuje',
    'Recurrent task is scheduled to be generated' => 'Opakovaná úloha je naplánovaná na vygenerovanie',
    'Score' => 'Skóre',
    'The identifier must be unique' => 'Identifikátor musí byť jedinečný',
    'This linked task id doesn\'t exists' => 'ID odkazovanej úlohy neexistuje',
    'This value must be alphanumeric' => 'Hodnota musí byť alfanumerická',
    'Edit recurrence' => 'Upraviť opakovanie',
    'Generate recurrent task' => 'Generovať opakovanú úlohu',
    'Trigger to generate recurrent task' => 'Spúšťač generovania opakovanej úlohy',
    'Factor to calculate new due date' => 'Faktor výpočtu nového termínu splnenia',
    'Timeframe to calculate new due date' => 'Časový rozvrh výpočtu nového termínu splnenia',
    'Base date to calculate new due date' => 'Základný dátum výpočtu nového termínu splnenia',
    'Action date' => 'Dátum akcie',
    'Base date to calculate new due date: ' => 'Základný dátum výpočtu nového termínu splnenia: ',
    'This task has created this child task: ' => 'Úloha vytvorila túto dcérsku úlohu: ',
    'Day(s)' => 'Deň(dni)',
    'Existing due date' => 'Existujúci termín splnenia',
    'Factor to calculate new due date: ' => 'Faktor výpočtu nového termínu splnenia: ',
    'Month(s)' => 'Mesiac(e)',
    'This task has been created by: ' => 'Túto úlohu vytvoril: ',
    'Recurrent task has been generated:' => 'Opakovaná úloha bola vygenerovaná:',
    'Timeframe to calculate new due date: ' => 'Časový rozvrh výpočtu nového termínu splnenia: ',
    'Trigger to generate recurrent task: ' => 'Spúšťač generovania opakovanej úlohy: ',
    'When task is closed' => 'Keď je úloha ukončená',
    'When task is moved from first column' => 'Keď je úloha presunutá z prvého stĺpca',
    'When task is moved to last column' => 'Keď je úloha presunutá do posledného stĺpca',
    'Year(s)' => 'Rok(y)',
    'Project settings' => 'Nastavenia projektu',
    'Automatically update the start date' => 'Automaticky aktualizovať dátum začiatku',
    'iCal feed' => 'Kanál iCal',
    'Preferences' => 'Nastavenia',
    'Security' => 'Bezpečnosť',
    'Two factor authentication disabled' => 'Dvojfaktorová autentifikácia zakázaná',
    'Two factor authentication enabled' => 'Dvojfaktorová autentifikácia povolená',
    'Unable to update this user.' => 'Nemožno aktualizovať tohoto používateľa.',
    'There is no user management for personal projects.' => 'Súkromné projekty nemajú správu používateľov.',
    'User that will receive the email' => 'Používateľ, ktorý dostane email',
    'Email subject' => 'Predmet emailu',
    'Date' => 'Dátum',
    'Add a comment log when moving the task between columns' => 'Pridať do záznamu komentár, keď je úloha presunutá medzi stĺpcami',
    'Move the task to another column when the category is changed' => 'Presunúť úlohu do iného stĺpca, keď je zmenená kategória',
    'Send a task by email to someone' => 'Poslať úlohu niekomu emailom',
    'Reopen a task' => 'Znova tvoriť úlohu',
    'Notification' => 'Upozornenie',
    '%s moved the task #%d to the first swimlane' => '%s presunul úlohu #%d do prvej dráhy',
    'Swimlane' => 'Dráha',
    '%s moved the task %s to the first swimlane' => '%s presunul úlohu %s do prvej dráhy',
    '%s moved the task %s to the swimlane "%s"' => '%s presunul úlohu %s do dráhy „%s”',
    'This report contains all subtasks information for the given date range.' => 'Tento výstup obsahuje informácie o všetkých podúlohách v zadanom rozsahu dátumov.',
    'This report contains all tasks information for the given date range.' => 'Tento výstup obsahuje všetky úlohy v zadanom rozsahu dátumov.',
    'Project activities for %s' => 'Aktivity projektu %s',
    'view the board on Kanboard' => 'zobraziť v nástenke Kanboard',
    'The task has been moved to the first swimlane' => 'Úloha bola presunutá do prvej dráhy',
    'The task has been moved to another swimlane:' => 'Úloha bola presunutá do inej dráhy:',
    'New title: %s' => 'Nový názov: %s',
    'The task is not assigned anymore' => 'Úloha už viac nie je pridelená',
    'New assignee: %s' => 'Nové pridelenie: %s',
    'There is no category now' => 'Teraz žiadna kategória',
    'New category: %s' => 'Nová kategória. %s',
    'New color: %s' => 'Nová farba: %s',
    'New complexity: %d' => 'Nová zložitosť: %d',
    'The due date has been removed' => 'Termín splnenia odstránený',
    'There is no description anymore' => 'Už viac nemá popis',
    'Recurrence settings has been modified' => 'Nastavenia opakovania boli zmenené',
    'Time spent changed: %sh' => 'Strávený čas zmenený: %s hod',
    'Time estimated changed: %sh' => 'Predpokladaný čas zmenený: %s hod',
    'The field "%s" has been updated' => 'Pole „%s” bolo aktualizované',
    'The description has been modified:' => 'Popis bol zmenený:',
    'Do you really want to close the task "%s" as well as all subtasks?' => 'Naozaj chcete ukončiť úlohu „%s” spolu so všetkými podúlohami?',
    'I want to receive notifications for:' => 'Chcem dostávať upozornenia na:',
    'All tasks' => 'Všetky úlohy',
    'Only for tasks assigned to me' => 'Len úlohy pridelené mne',
    'Only for tasks created by me' => 'Len mnou vytvorené úlohy',
    'Only for tasks created by me and tasks assigned to me' => 'Len mnou vytvorené a mne pridelené úlohy',
    '%%Y-%%m-%%d' => '%%d. %%m. %%Y',
    'Total for all columns' => 'Celkom všetky stĺpce',
    'You need at least 2 days of data to show the chart.' => 'Na zobrazenie diagramu sú potrebné dáta aspoň za dva dni.',
    '<15m' => '<15 m',
    '<30m' => '<30 m',
    'Stop timer' => 'Zastaviť časovač',
    'Start timer' => 'Spustiť časovač',
    'My activity stream' => 'Moja aktivita',
    'Search tasks' => 'Hľadať úlohy',
    'Reset filters' => 'Vymazať filtre',
    'My tasks due tomorrow' => 'Moje zajtrajšie úlohy',
    'Tasks due today' => 'Dnešné úlohy',
    'Tasks due tomorrow' => 'Zajtrajšie úlohy',
    'Tasks due yesterday' => 'Včerajšie úlohy',
    'Closed tasks' => 'Ukončené úlohy',
    'Open tasks' => 'Otvorené úlohy',
    'Not assigned' => 'Nepridelené',
    'View advanced search syntax' => 'Zobraziť syntax pokročilého hľadania',
    'Overview' => 'Prehľad',
    'Board/Calendar/List view' => 'Zobrazenie Nástenky/Kalendára/Zoznamu',
    'Switch to the board view' => 'Prepnúť do zobrazenia nástenky',
    'Switch to the list view' => 'Prepnúť do zobrazenia zoznamu',
    'Go to the search/filter box' => 'Prejsť do poľa hľadania/filtra',
    'There is no activity yet.' => 'Zatiaľ žiadna aktivita.',
    'No tasks found.' => 'Nenájdené žiadne úlohy.',
    'Keyboard shortcut: "%s"' => 'Klávesová skratka: „%s”',
    'List' => 'Zoznam',
    'Filter' => 'Filter',
    'Advanced search' => 'Pokročilé hľadanie',
    'Example of query: ' => 'Príklad dopytu: ',
    'Search by project: ' => 'Hľadať podľa projektu: ',
    'Search by column: ' => 'Hľadať podľa stĺpca: ',
    'Search by assignee: ' => 'Hľadať podľa pridelenia: ',
    'Search by color: ' => 'Hľadať podľa farby: ',
    'Search by category: ' => 'Hľadať podľa kategórie: ',
    'Search by description: ' => 'Hľadať podľa popisu: ',
    'Search by due date: ' => 'Hľadať podľa dátumu splnenia: ',
    'Average time spent in each column' => 'Priemerný čas strávený v každom stĺpci',
    'Average time spent' => 'Priemerne strávený čas',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Tento diagram zobrazuje priemerný čas cyklu a trvania posledných %d úloh.',
    'Average Lead and Cycle time' => 'Priemerný čas trvania a cyklu',
    'Average lead time: ' => 'Priemerný čas trvania: ',
    'Average cycle time: ' => 'Priemerný čas cyklu: ',
    'Cycle Time' => 'Čas cyklu',
    'Lead Time' => 'Čas trvania',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Tento diagram zobrazuje priemerný čas cyklu a trvania posledných %d úloh v čase.',
    'Average time into each column' => 'Priemerný čas v stĺpci',
    'Lead and cycle time' => 'Čas trvania a cyklu',
    'Lead time: ' => 'Čas trvania: ',
    'Cycle time: ' => 'Čas cyklu: ',
    'Time spent in each column' => 'Čas strávený v každom stĺpci',
    'The lead time is the duration between the task creation and the completion.' => 'Čas trvania je doba medzi vytvorením úlohy a jej ukončením.',
    'The cycle time is the duration between the start date and the completion.' => 'Čas cyklu je doba medzi začatím úlohy a jej ukončením.',
    'If the task is not closed the current time is used instead of the completion date.' => 'Ak úloha nie je ukončená, je namiesto času ukončenia použitý aktuálny čas.',
    'Set the start date automatically' => 'Automaticky nastaviť dátum začiatku',
    'Edit Authentication' => 'Upraviť Autentifikáciu',
    'Remote user' => 'Vzdialený používateľ',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Vzdialení používatelia nemajú uložené svoje heslo v databáze Kanboard, príklady: LDAP, účty Google a Github.',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Ak označíte zaškrtávacie pole „Zakázať prihlasovací formulár”, prihlasovacie údaje zadané v prihlasovacom formulári budú ignorované.',
    'Default task color' => 'Predvolená farba úlohy',
    'This feature does not work with all browsers.' => 'Táto vlastnosť nefunguje vo všetkých prehliadačoch.',
    'There is no destination project available.' => 'Cieľový projekt nie je dostupný.',
    'Trigger automatically subtask time tracking' => 'Automaticky spustiť sledovanie času podúlohy',
    'Include closed tasks in the cumulative flow diagram' => 'V kumulatívnom diagrame toku zahrnúť aj ukončené úlohy',
    'Current swimlane: %s' => 'Aktuálna dráha: %s',
    'Current column: %s' => 'Aktuálny stĺpec: %s',
    'Current category: %s' => 'Aktuálna kategória: %s',
    'no category' => 'žiadna kategória',
    'Current assignee: %s' => 'Aktuálne pridelené: %s',
    'not assigned' => 'nepridelené',
    'Author:' => 'Autor:',
    'contributors' => 'prispievatelia',
    'License:' => 'Licencia:',
    'License' => 'Licencia',
    'Enter the text below' => 'Zadajte nasledujúci text',
    'Start date:' => 'Dátum začiatku:',
    'Due date:' => 'Termín ukončenia:',
    'People who are project managers' => 'Ľudia, ktorí sú správcovia projektu',
    'People who are project members' => 'Ľudia, ktorí sú členovia projektu',
    'NOK - Norwegian Krone' => 'NOK – Nórska koruna',
    'Show this column' => 'Zobraziť tento stĺpec',
    'Hide this column' => 'Skryť tento stĺpec',
    'End date' => 'Dátum ukončenia',
    'Users overview' => 'Prehľad používateľov',
    'Members' => 'Členovia',
    'Shared project' => 'Zdieľané projekty',
    'Project managers' => 'Správcovia projektu',
    'Projects list' => 'Zoznam projektov',
    'End date:' => 'Dátum ukončenia:',
    'Change task color when using a specific task link' => 'Zmeniť farbu úlohy, pri použití daného odkazu na úlohu',
    'Task link creation or modification' => 'Vytvorenie alebo úprava odkazu na úlohu',
    'Milestone' => 'Míľnik',
    'Reset the search/filter box' => 'Vymazať pole hľadania/filtra',
    'Documentation' => 'Dokumentácia',
    'Author' => 'Autor',
    'Version' => 'Verzia',
    'Plugins' => 'Zásuvné moduly',
    'There is no plugin loaded.' => 'Žiadne načítané zásuvné moduly.',
    'My notifications' => 'Moje upozornenia',
    'Custom filters' => 'Vlastné filtre',
    'Your custom filter has been created successfully.' => 'Váš vlastný filter bol úspešne vytvorený.',
    'Unable to create your custom filter.' => 'Nemožno vytvoriť Váš vlastný filter.',
    'Custom filter removed successfully.' => 'Vlastný filter úspešne odstránený.',
    'Unable to remove this custom filter.' => 'Nemožno odstrániť vlastný filter.',
    'Edit custom filter' => 'Upraviť vlastný filter',
    'Your custom filter has been updated successfully.' => 'Vlastný filter bol úspešne aktualizovaný.',
    'Unable to update custom filter.' => 'Nemožno aktualizovať vlastný filter.',
    'Web' => 'Web',
    'New attachment on task #%d: %s' => 'Nová príloha úlohy #%d: %s',
    'New comment on task #%d' => 'Nový komentár úlohy #%d',
    'Comment updated on task #%d' => 'Aktualizovaný komentár úlohy #%d',
    'New subtask on task #%d' => 'Nová podúloha úlohy #%d',
    'Subtask updated on task #%d' => 'Aktualizovaná podúloha úlohy #%d',
    'New task #%d: %s' => 'Nová úloha #%d: %s',
    'Task updated #%d' => 'Aktualizovaná úloha #%d',
    'Task #%d closed' => 'Úloha #%d ukončená',
    'Task #%d opened' => 'Úloha #%d otvorená',
    'Column changed for task #%d' => 'Zmenený stĺpec úlohy #%d',
    'New position for task #%d' => 'Nová pozícia úlohy #%d',
    'Swimlane changed for task #%d' => 'Zmenená dráha úlohy #%d',
    'Assignee changed on task #%d' => 'Zmenené pridelenie úlohy #%d',
    '%d overdue tasks' => '%d úloh po termíne',
    'No notification.' => 'Žiadne upozornenia.',
    'Mark all as read' => 'Označiť všetky ako prečítané',
    'Mark as read' => 'Označiť ako prečítané',
    'Total number of tasks in this column across all swimlanes' => 'Celkový počet úloh tohoto stĺpca vo všetkých dráhach',
    'Collapse swimlane' => 'Zbaliť cestu',
    'Expand swimlane' => 'Rozbaliť cestu',
    'Add a new filter' => 'Pridať nový filter',
    'Share with all project members' => 'Zdieľať so všetkými členmi projektu',
    'Shared' => 'Zdieľané',
    'Owner' => 'Vlastník',
    'Unread notifications' => 'Neprečítané upozornenia',
    'Notification methods:' => 'Metódy upozornení:',
    'Unable to read your file' => 'Nemožno čítať zadaný súbor',
    '%d task(s) have been imported successfully.' => '%d úloha(y) úspešne importovaná/é.',
    'Nothing has been imported!' => 'Nebolo importované nič',
    'Import users from CSV file' => 'Importovať používateľov zo súboru CSV',
    '%d user(s) have been imported successfully.' => '%d požívateľ(ia) úspešne importovaní.',
    'Comma' => 'čiarka',
    'Semi-colon' => 'bodkočiarka',
    'Tab' => 'tabulátor',
    'Vertical bar' => 'zvislá čiara',
    'Double Quote' => 'úvodzovky',
    'Single Quote' => 'apostrofy',
    '%s attached a file to the task #%d' => '%s pripojil súbor k úlohe #%d',
    'There is no column or swimlane activated in your project!' => 'V tomto projekte nie sú aktivované stĺpce alebo dráhy',
    'Append filter (instead of replacement)' => 'Pridať filter (namiesto nahradenia)',
    'Append/Replace' => 'Pridať/Nahradiť',
    'Append' => 'Pridať',
    'Replace' => 'Nahradiť',
    'Import' => 'Importovať',
    'Change sorting' => 'Zmeniť radenie',
    'Tasks Importation' => 'Import úloh',
    'Delimiter' => 'Oddeľovač',
    'Enclosure' => 'Uzavretie',
    'CSV File' => 'Súbor CSV',
    'Instructions' => 'Pokyny',
    'Your file must use the predefined CSV format' => 'Súbor musí používať prednastavený formát CSV',
    'Your file must be encoded in UTF-8' => 'Súbor musí byť kódovaný v UTF-8',
    'The first row must be the header' => 'Prvý riadok musí byť hlavička',
    'Duplicates are not verified for you' => 'Duplikáty nie sú kontrolované',
    'The due date must use the ISO format: YYYY-MM-DD' => 'Dátum ukončenia musí byť vo formáte ISO: RRRR-MM-DD',
    'Download CSV template' => 'Stiahnuť šablónu CSV',
    'No external integration registered.' => 'Nie je zaregistrovaná externá integrácia.',
    'Duplicates are not imported' => 'Duplikáta nie sú importované',
    'Usernames must be lowercase and unique' => 'Mená používateľov musia byť malými písmenami a jedinečné',
    'Passwords will be encrypted if present' => 'Heslá, ak existujú, budú šifrované',
    '%s attached a new file to the task %s' => '%s pripojil nový súbor k úlohe %s',
    'Link type' => 'Typ odkazu',
    'Assign automatically a category based on a link' => 'Automaticky nastaviť kategóriu na základe odkazu',
    'BAM - Konvertible Mark' => 'BAM – Konvertibilná marka',
    'Assignee Username' => 'Prihl. meno pridelenia',
    'Assignee Name' => 'Meno pridelenia',
    'Groups' => 'Skupiny',
    'Members of %s' => 'Členovia %s',
    'New group' => 'Nová skupina',
    'Group created successfully.' => 'Skupina úspešne vytvorená.',
    'Unable to create your group.' => 'Nemožno vytvoriť skupinu.',
    'Edit group' => 'Upraviť skupinu',
    'Group updated successfully.' => 'Skupina úspešne aktualizovaná.',
    'Unable to update your group.' => 'Nemožno aktualizovať skupinu.',
    'Add group member to "%s"' => 'Pridať člena skupiny do „%s”',
    'Group member added successfully.' => 'Člen skupiny úspešne pridaný.',
    'Unable to add group member.' => 'Nemožno pridať člena skupiny.',
    'Remove user from group "%s"' => 'Odstrániť používateľa zo skupiny „%s”',
    'User removed successfully from this group.' => 'Používateľ úspešne odstránený zo skupiny.',
    'Unable to remove this user from the group.' => 'Nemožno odstrániť používateľa zo skupiny.',
    'Remove group' => 'Odstrániť skupinu',
    'Group removed successfully.' => 'Skupina úspešne odstránená.',
    'Unable to remove this group.' => 'Nemožno odstrániť skupinu.',
    'Project Permissions' => 'Povolenia projektu',
    'Manager' => 'Správca',
    'Project Manager' => 'Správca projektu',
    'Project Member' => 'Člen projektu',
    'Project Viewer' => 'Čitateľ projektu',
    'Your account is locked for %d minutes' => 'Váš účet je zamknutý na %d min',
    'Invalid captcha' => 'Neplatná CAPTCHA',
    'The name must be unique' => 'Meno musí byť jedinečné',
    'View all groups' => 'Zobraziť všetky skupiny',
    'There is no user available.' => 'Nie je dostupný žiadny používateľ.',
    'Do you really want to remove the user "%s" from the group "%s"?' => 'Naozaj chcete odstrániť používateľa „%s” zo skupiny „%s”?',
    'There is no group.' => 'Nie je tu žiadna skupina.',
    'Add group member' => 'Pridať člena skupiny',
    'Do you really want to remove this group: "%s"?' => 'Naozaj chcete odstrániť skupinu: „%s”?',
    'There is no user in this group.' => 'Žiadny používatelia tejto skupiny.',
    'Permissions' => 'Povolenia',
    'Allowed Users' => 'Povolení používatelia',
    'No specific user has been allowed.' => 'Žiadni výslovne povolení používatelia.',
    'Role' => 'Rola',
    'Enter user name...' => 'Zadajte prihlasovacie meno...',
    'Allowed Groups' => 'Povolené skupiny',
    'No group has been allowed.' => 'Žiadne výslovne povolené skupiny.',
    'Group' => 'Skupiny',
    'Group Name' => 'Meno skupiny',
    'Enter group name...' => 'Zadajte meno skupiny...',
    'Role:' => 'Rola:',
    'Project members' => 'Členovia projektu',
    '%s mentioned you in the task #%d' => '%s Vás spomenul v úlohe #%d',
    '%s mentioned you in a comment on the task #%d' => '%s Vás spomenul v komentári úlohy #%d',
    'You were mentioned in the task #%d' => 'Boli ste spomenutý v úlohe #%d',
    'You were mentioned in a comment on the task #%d' => 'Boli ste spomenutý v komentári úlohy #%d',
    'Estimated hours: ' => 'Očakávané hodiny: ',
    'Actual hours: ' => 'Aktuálne hodiny: ',
    'Hours Spent' => 'Strávených hodín',
    'Hours Estimated' => 'Plánovaných hodín',
    'Estimated Time' => 'Plánovaný čas',
    'Actual Time' => 'Aktuálny čas',
    'Estimated vs actual time' => 'Očakávaný a aktuálny čas',
    'RUB - Russian Ruble' => 'RUB – Ruský rubeľ',
    'Assign the task to the person who does the action when the column is changed' => 'Prideliť úlohu osobe, ktorá vykonala akciu so zmenou stĺpca',
    'Close a task in a specific column' => 'Ukončiť úlohu v zadanom stĺpci',
    'Time-based One-time Password Algorithm' => 'Algoritmus časovo obmedzeného jednoúčelového hesla',
    'Two-Factor Provider: ' => 'Poskytovateľ dvojfaktoru: ',
    'Disable two-factor authentication' => 'Vypnúť dvojfaktorovú autentifikáciu',
    'Enable two-factor authentication' => 'Zapnúť dvojfaktorovú autentifikáciu',
    'There is no integration registered at the moment.' => 'Momentálne žiadna registrovaná integrácia.',
    'Password Reset for Kanboard' => 'Obnova hesla pre Kanboard',
    'Forgot password?' => 'Zabudli ste heslo?',
    'Enable "Forget Password"' => 'Zapnúť „Zabudnuté heslo”',
    'Password Reset' => 'Obnovenie hesla',
    'New password' => 'Nové heslo',
    'Change Password' => 'Zmeniť heslo',
    'To reset your password click on this link:' => 'Na obnovu hesla kliknite na nasledujúci odkaz:',
    'Last Password Reset' => 'Posledná obnova hesla',
    'The password has never been reinitialized.' => 'Heslo nebolo nikdy obnovované.',
    'Creation' => 'Vytvorenie',
    'Expiration' => 'Vypršanie',
    'Password reset history' => 'História obnovenia hesla',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Všetky úlohy stĺpca „%s” a dráhy „%s” boli úspešne ukončené.',
    'Do you really want to close all tasks of this column?' => 'Naozaj chcete ukončiť všetky úlohy tohoto stĺpca?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d úloha(y) v stĺpci „%s” a dráhy „%s” budú ukončené.',
    'Close all tasks in this column and this swimlane' => 'Ukončiť všetky úlohy tohoto stĺpca',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Žiadny zásuvný modul nemá zaregistrovanú metódu upozornení projektu. I tak môžete nastaviť jednotlivé upozornenia vo svojom profile.',
    'My dashboard' => 'Moja nástenka',
    'My profile' => 'Môj profil',
    'Project owner: ' => 'Vlastník projektu: ',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'Identifikátor projektu je voliteľný a musí byť alfanumerický, napr. MOJPORJEKT.',
    'Project owner' => 'Vlastník projektu',
    'Personal projects do not have users and groups management.' => 'Súkromné projekty nemajú správu používateľov a skupín.',
    'There is no project member.' => 'Žiadny člen projektu.',
    'Priority' => 'Priorita',
    'Task priority' => 'Priorita úlohy',
    'General' => 'Všeobecné',
    'Dates' => 'Dátumy',
    'Default priority' => 'Predvolená priorita',
    'Lowest priority' => 'Najnižšia priorita',
    'Highest priority' => 'Najvyššia priorita',
    'Close a task when there is no activity' => 'Ukončiť úlohu, ak je bez aktivity',
    'Duration in days' => 'Trvanie v dňoch',
    'Send email when there is no activity on a task' => 'Poslať email, keď nenastala aktivita s úlohou',
    'Unable to fetch link information.' => 'Nemožno získať informácie odkazu.',
    'Daily background job for tasks' => 'Denná úloha na pozadí pre úlohy',
    'Auto' => 'Auto',
    'Related' => 'Súvisí',
    'Attachment' => 'Prílohy',
    'Web Link' => 'Webový odkaz',
    'External links' => 'Externé odkazy',
    'Add external link' => 'Pridať externý odkaz',
    'Type' => 'Typ',
    'Dependency' => 'Závislosť',
    'Add internal link' => 'Pridať interný odkaz',
    'Add a new external link' => 'Pridať nový externý odkaz',
    'Edit external link' => 'Upraviť externý odkaz',
    'External link' => 'Externý odkaz',
    'Copy and paste your link here...' => 'Prekopírujte a vložte svoj odkaz tu...',
    'URL' => 'URL',
    'Internal links' => 'Interné odkazy',
    'Assign to me' => 'Prideliť mne',
    'Me' => 'mne',
    'Do not duplicate anything' => 'Nič neduplikovať',
    'Projects management' => 'Správa projektov',
    'Users management' => 'Správa používateľov',
    'Groups management' => 'Správa skupín',
    'Create from another project' => 'Vytvoriť z iného projektu',
    'open' => 'otvorený',
    'closed' => 'ukončený',
    'Priority:' => 'Priorita:',
    'Reference:' => 'Odkaz:',
    'Complexity:' => 'Zložitosť:',
    'Swimlane:' => 'Dráha:',
    'Column:' => 'Stĺpec:',
    'Position:' => 'Pozícia:',
    'Creator:' => 'Autor:',
    'Time estimated:' => 'Predpokladaný čas:',
    '%s hours' => '%s hod',
    'Time spent:' => 'Strávený čas:',
    'Created:' => 'Vytvorené:',
    'Modified:' => 'Zmenené:',
    'Completed:' => 'Dokončené:',
    'Started:' => 'Začaté:',
    'Moved:' => 'Presunuté:',
    'Task #%d' => 'Úloha #%d',
    'Time format' => 'Formát času',
    'Start date: ' => 'Dátum začiatku: ',
    'End date: ' => 'Dátum ukončenia: ',
    'New due date: ' => 'Nový termín splnenia: ',
    'Start date changed: ' => 'Dátum začiatku zmenený: ',
    'Disable personal projects' => 'Vypnúť súkromné projekty',
    'Do you really want to remove this custom filter: "%s"?' => 'Naozaj chcete odstrániť vlastný filter: „%s”?',
    'Remove a custom filter' => 'Odstrániť vlastný filter',
    'User activated successfully.' => 'Používateľ úspešne aktivovaný.',
    'Unable to enable this user.' => 'Nemožno povoliť tohoto používateľa.',
    'User disabled successfully.' => 'Používateľ úspešne zakázaný.',
    'Unable to disable this user.' => 'Nemožno zakázať tohoto používateľa.',
    'All files have been uploaded successfully.' => 'Všetky súbory úspešne nahrané.',
    'The maximum allowed file size is %sB.' => 'Maximálna povolená veľkosť súboru je %sB.',
    'Drag and drop your files here' => 'Pretiahnite svoje súbory tu',
    'choose files' => 'zvoľte súbory',
    'View profile' => 'Zobraziť profil',
    'Two Factor' => 'Dvojfaktor',
    'Disable user' => 'Zakázať používateľa',
    'Do you really want to disable this user: "%s"?' => 'Naozaj chcete zakázať používateľa: „%s”?',
    'Enable user' => 'Povoliť používateľa',
    'Do you really want to enable this user: "%s"?' => 'Naozaj chcete povoliť používateľa: „%s”?',
    'Download' => 'Stiahnuť',
    'Uploaded: %s' => 'Nahrané: %s',
    'Size: %s' => 'Veľkosť: %s',
    'Uploaded by %s' => 'Nahral %s',
    'Filename' => 'Meno súboru',
    'Size' => 'Veľkosť',
    'Column created successfully.' => 'Stĺpec úspešne vytvorený.',
    'Another column with the same name exists in the project' => 'V projekte už existuje iný stĺpec s rovnakým menom',
    'Default filters' => 'Predvolené filtre',
    'Your board doesn\'t have any columns!' => 'Vaša nástenka nemá žiadne stĺpce!',
    'Change column position' => 'Zmeniť pozíciu stĺpca',
    'Switch to the project overview' => 'Prepnúť na prehľad projektu',
    'User filters' => 'Filtre používateľa',
    'Category filters' => 'Filtre kategórie',
    'Upload a file' => 'Nahrať súbor',
    'View file' => 'Zobraziť súbor',
    'Last activity' => 'Nedávna aktivita',
    'Change subtask position' => 'Zmeniť pozíciu podúlohy',
    'This value must be greater than %d' => 'Táto hodnota musí byť väčšia ako %d',
    'Another swimlane with the same name exists in the project' => 'V projekte už existuje iná dráha s rovnakým menom',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Príklad: https://kanboard.example.org/ (slúži na generovanie absolútnych URL)',
    'Actions duplicated successfully.' => 'Akcie úspešne duplikované.',
    'Unable to duplicate actions.' => 'Nemožno duplikovať akciu.',
    'Add a new action' => 'Pridať novú akciu',
    'Import from another project' => 'Importovať z iného projektu',
    'There is no action at the moment.' => 'Momentálne žiadne akcie.',
    'Import actions from another project' => 'Importovať akcie z iného projektu',
    'There is no available project.' => 'Žiadny dostupný projekt.',
    'Local File' => 'Lokálny súbor',
    'Configuration' => 'Nastavenia',
    'PHP version:' => 'Verzia PHP:',
    'PHP SAPI:' => 'PHP SAPI:',
    'OS version:' => 'Verzia OS:',
    'Database version:' => 'Verzia databázy:',
    'Browser:' => 'Prehliadač:',
    'Task view' => 'Zobrazenie úlohy',
    'Edit task' => 'Upraviť úlohu',
    'Edit description' => 'Upraviť popis',
    'New internal link' => 'Nový interný odkaz',
    'Display list of keyboard shortcuts' => 'Zobraziť zoznam klávesových skratiek',
    'Avatar' => 'Avatar',
    'Upload my avatar image' => 'Nahrať obrázok svojho avatara',
    'Remove my image' => 'Odstrániť svoj obrázok',
    'The OAuth2 state parameter is invalid' => 'Parameter stavu OAuth2 je neplatný',
    'User not found.' => 'Používateľ nenájdený.',
    'Search in activity stream' => 'Hľadať v prehľade aktivity',
    'My activities' => 'Moje aktivity',
    'Activity until yesterday' => 'Aktivita do včera',
    'Activity until today' => 'Aktivita do dnes',
    'Search by creator: ' => 'Hľadať podľa autora: ',
    'Search by creation date: ' => 'Hľadať podľa dátumu vytvorenia: ',
    'Search by task status: ' => 'Hľadať podľa stavu úlohy: ',
    'Search by task title: ' => 'Hľadať podľa názvu úlohy: ',
    'Activity stream search' => 'Hľadanie v prehľade aktivity',
    'Projects where "%s" is manager' => 'Projekty, kde je správcom „%s”',
    'Projects where "%s" is member' => 'Projekty, kde je členom „%s”',
    'Open tasks assigned to "%s"' => 'Otvorené úlohy pridelené „%s”',
    'Closed tasks assigned to "%s"' => 'Ukončené úlohy pridelené „%s”',
    'Assign automatically a color based on a priority' => 'Automaticky nastaviť farbu na základe priority',
    'Overdue tasks for the project(s) "%s"' => 'Úlohy po termíne projektu(ov) „%s”',
    'Upload files' => 'Nahrať súbory',
    'Installed Plugins' => 'Nainštalované zásuvné moduly',
    'Plugin Directory' => 'Zložka zásuvných modulov',
    'Plugin installed successfully.' => 'Zásuvný modul úspešne nainštalovaný.',
    'Plugin updated successfully.' => 'Zásuvný modul úspešne aktualizovaný.',
    'Plugin removed successfully.' => 'Zásuvný modul úspešne odstránený.',
    'Subtask converted to task successfully.' => 'Podúloha úspešne konvertovaná na úlohu.',
    'Unable to convert the subtask.' => 'Nemožno konvertovať podúlohu.',
    'Unable to extract plugin archive.' => 'Nemožno rozbaliť archív zásuvného modulu.',
    'Plugin not found.' => 'Zásuvný modul nenájdený.',
    'You don\'t have the permission to remove this plugin.' => 'Nemáte práva na odstránenie tohoto zásuvného modulu.',
    'Unable to download plugin archive.' => 'Nemožno stiahnuť archív zásuvného modulu.',
    'Unable to write temporary file for plugin.' => 'Nemožno zapísať dočasný súbor zásuvného modulu.',
    'Unable to open plugin archive.' => 'Nemožno otvoriť archív zásuvného modulu.',
    'There is no file in the plugin archive.' => 'V archíve zásuvného modulu nie je súbor.',
    'Create tasks in bulk' => 'Hromadné vytvorenie úloh',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'Táto inštalácia Kanboard nie je nastavená na inštaláciu zásuvných modulov z používateľského rozhrania.',
    'There is no plugin available.' => 'Žiadne dostupné zásuvné moduly.',
    'Install' => 'Inštalovať',
    'Update' => 'Aktualizovať',
    'Up to date' => 'Aktuálny',
    'Not available' => 'Nedostupný',
    'Remove plugin' => 'Odstrániť zásuvný modul',
    'Do you really want to remove this plugin: "%s"?' => 'Naozaj chcete odstrániť zásuvný modul: „%s”?',
    'Uninstall' => 'Odinštalovať',
    'Listing' => 'Zoznam',
    'Metadata' => 'Metadáta',
    'Manage projects' => 'Správa projektov',
    'Convert to task' => 'Konvertovať na úlohu',
    'Convert sub-task to task' => 'Konvertovať podúlohu na úlohu',
    'Do you really want to convert this sub-task to a task?' => 'Naozaj chcete konvertovať túto podúlohu na úlohu?',
    'My task title' => 'Názov mojej úlohy',
    'Enter one task by line.' => 'Zadajte jednu úlohu na riadok.',
    'Number of failed login:' => 'Počet zlyhaných prihlásení:',
    'Account locked until:' => 'Účet uzamknutý do:',
    'Email settings' => 'Nastavenia emailu',
    'Email sender address' => 'Adresa odosielateľa',
    'Email transport' => 'Emailový transport',
    'Webhook token' => 'Token webového háku',
    'Project tags management' => 'Správa značiek projektu',
    'Tag created successfully.' => 'Značka úspešne vytvorená.',
    'Unable to create this tag.' => 'Nemožno vytvoriť túto značku.',
    'Tag updated successfully.' => 'Značka úspešne zmenená.',
    'Unable to update this tag.' => 'Nemožno upraviť túto značku.',
    'Tag removed successfully.' => 'Značka úspešne odstránená.',
    'Unable to remove this tag.' => 'Nemožno odstrániť túto značku.',
    'Global tags management' => 'Správa globálnych značiek',
    'Tags' => 'Značky',
    'Tags management' => 'Správa značiek',
    'Add new tag' => 'Pridať novú značku',
    'Edit a tag' => 'Upraviť značku',
    'Project tags' => 'Značky projektu',
    'There is no specific tag for this project at the moment.' => 'Momentálne tento projekt nemá žiadnu konkrétnu značku.',
    'Tag' => 'Značka',
    'Remove a tag' => 'Odstrániť značku',
    'Do you really want to remove this tag: "%s"?' => 'Naozaj chcete odstrániť značku: „%s”?',
    'Global tags' => 'Globálne značky',
    'There is no global tag at the moment.' => 'Momentálne žiadne globálne značky.',
    'This field cannot be empty' => 'Toto pole nemôže byť prázdne',
    'Close a task when there is no activity in a specific column' => 'Ukončiť úlohu, ak nebola aktivita v zadanom stĺpci',
    '%s removed a subtask for the task #%d' => '%s odstránil podúlohu úlohy #%d',
    '%s removed a comment on the task #%d' => '%s odstránil komentár úlohy #%d',
    'Comment removed on task #%d' => 'Odstránený komentár úlohy #%d',
    'Subtask removed on task #%d' => 'Odstránená podúloha úlohy #%d',
    'Hide tasks in this column in the dashboard' => 'Skryť úlohy tohoto stĺpca v nástenke',
    '%s removed a comment on the task %s' => '%s odstránil komentár úlohy %s',
    '%s removed a subtask for the task %s' => '%s odstránil podúlohu úlohy %s',
    'Comment removed' => 'Komentár odstránený',
    'Subtask removed' => 'Podúloha odstránená',
    '%s set a new internal link for the task #%d' => '%s nastavil  nový interný odkaz úlohy #%d',
    '%s removed an internal link for the task #%d' => '%s odstránil interný odkaz úlohy #%d',
    'A new internal link for the task #%d has been defined' => 'Bol definovaný nový interný odkaz úlohy #%d',
    'Internal link removed for the task #%d' => 'Odstránený interný odkaz úlohy #%d',
    '%s set a new internal link for the task %s' => '%s vytvoril nový interný odkaz úlohy %s',
    '%s removed an internal link for the task %s' => '%s odstránil interný odkaz úlohy %s',
    'Automatically set the due date on task creation' => 'Automaticky nastaviť termín splnenia pri vytvorení úlohy',
    'Move the task to another column when closed' => 'Presunúť úlohu do iného stĺpca pri ukončení',
    'Move the task to another column when not moved during a given period' => 'Presunúť úlohu do iného stĺpca, ak nebola presunutá po zadanú dobu',
    'Dashboard for %s' => 'Nástenka %s',
    'Tasks overview for %s' => 'Prehľad úloh %s',
    'Subtasks overview for %s' => 'Prehľad podúloh %s',
    'Projects overview for %s' => 'Prehľad projektov %s',
    'Activity stream for %s' => 'Prúd aktivity %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Nastaviť farbu, keď je úloha presunutá do zadanej dráhy',
    'Assign a priority when the task is moved to a specific swimlane' => 'Nastaviť prioritu, keď je úloha presunutá do zadanej dráhy',
    'User unlocked successfully.' => 'Používateľ úspešne odomknutý.',
    'Unable to unlock the user.' => 'Nemožno odomknúť používateľa.',
    'Move a task to another swimlane' => 'Presunúť úlohu do inej dráhy',
    'Creator Name' => 'Meno autora',
    'Time spent and estimated' => 'Strávený a očakávaný čas',
    'Move position' => 'Presunúť pozíciu',
    'Move task to another position on the board' => 'Presunúť úlohu na inú pozíciu v nástenke',
    'Insert before this task' => 'Vložiť pred túto úlohu',
    'Insert after this task' => 'Vložiť za túto úlohu',
    'Unlock this user' => 'Odomknúť tohoto používateľa',
    'Custom Project Roles' => 'Vlastné role projektu',
    'Add a new custom role' => 'Pridať novú vlastnú rolu',
    'Restrictions for the role "%s"' => 'Obmedzenia roly „%s”',
    'Add a new project restriction' => 'Pridať nové obmedzenie projektu',
    'Add a new drag and drop restriction' => 'Pridať obmedzenie Ťahaj a Pusť',
    'Add a new column restriction' => 'Pridať obmedzenie nového stĺpca',
    'Edit this role' => 'Upraviť túto rolu',
    'Remove this role' => 'Odstrániť túto rolu',
    'There is no restriction for this role.' => 'Táto rola nemá žiadne obmedzenia.',
    'Only moving task between those columns is permitted' => 'Povolený je len presun úloh medzi týmito stĺpcami',
    'Close a task in a specific column when not moved during a given period' => 'Ukončiť úlohu v zadanom stĺpci, ak nebola presunutá počas zadanej doby',
    'Edit columns' => 'Upraviť stĺpce',
    'The column restriction has been created successfully.' => 'Obmedzenie stĺpca úspešne vytvorené.',
    'Unable to create this column restriction.' => 'Nemožno vytvoriť obmedzenie stĺpca.',
    'Column restriction removed successfully.' => 'Obmedzenie stĺpca úspešne vytvorené.',
    'Unable to remove this restriction.' => 'Nemožno odstrániť obmedzenie.',
    'Your custom project role has been created successfully.' => 'Vlastná rola projektu úspešne vytvorená.',
    'Unable to create custom project role.' => 'Nemožno vytvoriť vlastnú rolu projektu.',
    'Your custom project role has been updated successfully.' => 'Vlastná rola projektu úspešne aktualizovaná.',
    'Unable to update custom project role.' => 'Nemožno aktualizovať vlastnú rolu projektu.',
    'Custom project role removed successfully.' => 'Vlastná rola projektu úspešne vytvorená.',
    'Unable to remove this project role.' => 'Nemožno odstrániť rolu projektu.',
    'The project restriction has been created successfully.' => 'Obmedzenie projektu úspešne vytvorené.',
    'Unable to create this project restriction.' => 'Nemožno vytvoriť obmedzenie projektu.',
    'Project restriction removed successfully.' => 'Obmedzenie projektu úspešne odstránené.',
    'You cannot create tasks in this column.' => 'Nemôžete vytvoriť úlohu v tomto stĺpci.',
    'Task creation is permitted for this column' => 'Vytvorenie úloh povolené pre tento stĺpec',
    'Closing or opening a task is permitted for this column' => 'Otvorenie a ukončenie úloh je povolené pre tento stĺpec',
    'Task creation is blocked for this column' => 'Vytvorenie úloh je zakázané pre tento stĺpec',
    'Closing or opening a task is blocked for this column' => 'Otvorenie a ukončenie úloh je zakázané pre tento stĺpec',
    'Task creation is not permitted' => 'Vytvorenie úlohy nie je dovolené',
    'Closing or opening a task is not permitted' => 'Otvorenie a ukončenie úlohy nie je dovolené',
    'New drag and drop restriction for the role "%s"' => 'Nové obmedzenie Ťahaj a Pusť pre rolu „%s”',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Ľudia, ktorí patria do tejto roly, budú môcť presúvať úlohy len medzi zdrojovým a cieľovým stĺpcom.',
    'Remove a column restriction' => 'Odstrániť obmedzenie stĺpca',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Naozaj chcete odstrániť obmedzenie stĺpca: „%s” do „%s”?',
    'New column restriction for the role "%s"' => 'Nové obmedzenie stĺpca roly „%s”',
    'Rule' => 'Pravidlo',
    'Do you really want to remove this column restriction?' => 'Naozaj chcete odstrániť obmedzenie stĺpca?',
    'Custom roles' => 'Vlastné roly',
    'New custom project role' => 'Nová vlastná rola projektu',
    'Edit custom project role' => 'Upraviť vlastnú rolu projektu',
    'Remove a custom role' => 'Odstrániť vlastnú rolu projektu',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => 'Naozaj chcete odstrániť vlastnú rolu: „%s”? Všetci priradení k tejto role sa stanú členmi projektu.',
    'There is no custom role for this project.' => 'Tento projekt nemá vlastné roly.',
    'New project restriction for the role "%s"' => 'Nové obmedzenie roly projektu „%s”',
    'Restriction' => 'Obmedzenia',
    'Remove a project restriction' => 'Odstrániť obmedzenie projektu',
    'Do you really want to remove this project restriction: "%s"?' => 'naozaj chcete odstrániť obmedzenie projektu: „%s”?',
    'Duplicate to multiple projects' => 'Duplikovať do viacerých',
    'This field is required' => 'Toto pole je povinné',
    'Moving a task is not permitted' => 'Presun úlohy nie je povolený',
    'This value must be in the range %d to %d' => 'Táto hodnota musí byť v rozsahu %d – %d',
    'You are not allowed to move this task.' => 'Nemáte dovolené presunúť túto úlohu.',
    'API User Access' => 'Prístup API používateľa',
    'Preview' => 'Ukážka',
    'Write' => 'Písať',
    'Write your text in Markdown' => 'Napíšte svoj text v Markdown',
    'No personal API access token registered.' => 'Nie sú zaregistrované žiadne prístupové tokeny API.',
    'Your personal API access token is "%s"' => 'Váš osobný prístupový token API je „%s”',
    'Remove your token' => 'Odstrániť svoj token',
    'Generate a new token' => 'Generovať nový token',
    'Showing %d-%d of %d' => 'Zobrazené %d – %d z %d',
    'Outgoing Emails' => 'Odchádzajúce emaily',
    'Add or change currency rate' => 'Pridať alebo zmeniť konverzný kurz',
    'Reference currency: %s' => 'Referenčná mena: %s',
    'Add custom filters' => 'Pridať vlastné filtre',
    'Export' => 'Exportovať',
    'Add link label' => 'Pridať menovku odkazu',
    'Incompatible Plugins' => 'Nekompatibilné zásuvné moduly',
    'Compatibility' => 'Kompatibilita',
    'Permissions and ownership' => 'Povolenia a vlastníctvo',
    'Priorities' => 'Priority',
    'Close this window' => 'Zatvoriť okno',
    'Unable to upload this file.' => 'Nemožno nahrať tento súbor.',
    'Import tasks' => 'Importovať úlohy',
    'Choose a project' => 'Zvoľte projekt',
    'Profile' => 'Profile',
    'Application role' => 'Rola aplikácie',
    '%d invitations were sent.' => '%d pozvaní odoslaných.',
    '%d invitation was sent.' => '%d pozvanie odoslané.',
    'Unable to create this user.' => 'Nemožno vytvoriť používateľa.',
    'Kanboard Invitation' => 'Pozvánka Kanboard',
    'Visible on dashboard' => 'Viditeľné v nástenke',
    'Created at:' => 'Vytvorené:',
    'Updated at:' => 'Upravené:',
    'There is no custom filter.' => 'Žiadny vlastný filter.',
    'New User' => 'Nový používateľ',
    'Authentication' => 'Autentifikácia',
    'If checked, this user will use a third-party system for authentication.' => 'Ak je zvolené, tento používateľ bude používať na autentifikáciu systém tretej strany.',
    'The password is necessary only for local users.' => 'Heslo je potrebné len pre lokálnych používateľov.',
    'You have been invited to register on Kanboard.' => 'Boli ste pozvaný na registráciu v Kanboard.',
    'Click here to join your team' => 'Kliknite tu na vstup do tímu',
    'Invite people' => 'Pozvať',
    'Emails' => 'Emaily',
    'Enter one email address by line.' => 'Zadajte jednu emailovú adresu na riadok.',
    'Add these people to this project' => 'Pridať týchto ľudí do projektu',
    'Add this person to this project' => 'Pridať tohoto človeka do projektu',
    'Sign-up' => 'Registrovať',
    'Credentials' => 'Prihl. údaje',
    'New user' => 'Nový používateľ',
    'This username is already taken' => 'Prihlasovacie meno už je použité',
    'Your profile must have a valid email address.' => 'Váš profil musí mať platnú emailovú adresu.',
    'TRL - Turkish Lira' => 'TRL – Turecká líra',
    'The project email is optional and could be used by several plugins.' => 'Email projektu je voliteľný a môže byť použitý viacerými zásuvnými modulmi.',
    'The project email must be unique across all projects' => 'Email projektu musí byť jedinečný vo všetkých projektoch',
    'The email configuration has been disabled by the administrator.' => 'Nastavenie emailu bolo zakázané administrátorom.',
    'Close this project' => 'Ukončiť tento projekt',
    'Open this project' => 'Otvoriť tento projekt',
    'Close a project' => 'Ukončiť projekt',
    'Do you really want to close this project: "%s"?' => 'Naozaj chcete ukončiť projekt „%s”?',
    'Reopen a project' => 'Znova otvoriť projekt',
    'Do you really want to reopen this project: "%s"?' => 'Naozaj chcete znova otvoriť projekt: „%s”?',
    'This project is open' => 'Tento projekt je otvorený',
    'This project is closed' => 'Tento projekt je ukončený',
    'Unable to upload files, check the permissions of your data folder.' => 'Nemožno nahrať súbory, skontrolujte prístupové práva zložky „data”.',
    'Another category with the same name exists in this project' => 'Iná kategória s rovnakým menom existuje v toto projekte',
    'Comment sent by email successfully.' => 'Komentár úspešne odoslaný emailom.',
    'Sent by email to "%s" (%s)' => 'Poslané emailom „%s” (%s)',
    'Unable to read uploaded file.' => 'Nemožno čítať nahratý súbor.',
    'Database uploaded successfully.' => 'Databáza úspešne nahratá.',
    'Task sent by email successfully.' => 'Úloha úspešne odoslaná emailom.',
    'There is no category in this project.' => 'Tento projekt nemá kategórie.',
    'Send by email' => 'Odoslať emailom',
    'Create and send a comment by email' => 'Vytvoriť a poslať komentár emailom',
    'Subject' => 'Predmet',
    'Upload the database' => 'Nahrať databázu',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Môžete nahrať predtým stiahnutú databázu SQLite (formát Gzip).',
    'Database file' => 'Súbor databázy',
    'Upload' => 'Nahrať',
    'Your project must have at least one active swimlane.' => 'Projekt musí mať aspoň jednu aktívnu cestu.',
    'Project: %s' => 'Projekt: %s',
    'Automatic action not found: "%s"' => 'Automatická akcia nenájdená: „%s”',
    '%d projects' => '%d projekty(ov)',
    '%d project' => '%d projekt',
    'There is no project.' => 'Nie je tu žiadny projekt.',
    'Sort' => 'Radiť',
    'Project ID' => 'ID projektu',
    'Project name' => 'Názov projektu',
    'Public' => 'Verejný',
    'Personal' => 'Súkromný',
    '%d tasks' => '%d úloh(y)',
    '%d task' => '%d úloha',
    'Task ID' => 'ID úlohy',
    'Assign automatically a color when due date is expired' => 'Automaticky nastaviť farbu, po vypršaní termínu splnenia',
    'Total score in this column across all swimlanes' => 'Celkové skóre tohoto stĺpca vo všetkých dráhach',
    'HRK - Kuna' => 'HRK – Chorvátska kuna',
    'ARS - Argentine Peso' => 'ARS – Argentínske peso',
    'COP - Colombian Peso' => 'COP – Kolumbijské peso',
    '%d groups' => '%d skupiny(ín)',
    '%d group' => '%d skupina',
    'Group ID' => 'ID skupiny',
    'External ID' => 'Externé ID',
    '%d users' => '%d používatelia(ľov)',
    '%d user' => '%d používateľ',
    'Hide subtasks' => 'Skryť podúlohy',
    'Show subtasks' => 'Zobraziť podúlohy',
    'Authentication Parameters' => 'Autentifikačné parametre',
    'API Access' => 'Prístup API',
    'No users found.' => 'Nenájdení žiadny používatelia.',
    'User ID' => 'ID používateľa',
    'Notifications are activated' => 'Upozornenia sú aktivovaná',
    'Notifications are disabled' => 'Upozornenia sú zakázané',
    'User disabled' => 'Používateľ zakázaný',
    '%d notifications' => '%d upozornení',
    '%d notification' => '%d upozornenie',
    'There is no external integration installed.' => 'Nie je nainštalovaná žiadna externá integrácia.',
    'You are not allowed to update tasks assigned to someone else.' => 'Nemáte povolené upraviť úlohu pridelenú niekomu inému.',
    'You are not allowed to change the assignee.' => 'Nemáte dovolené zmeniť pridelenie.',
    'Task suppression is not permitted' => 'Potlačenie úlohy nie je povolené',
    'Changing assignee is not permitted' => 'Zmena pridelenia nie je dovolená',
    'Update only assigned tasks is permitted' => 'Povolená je len aktualizácia pridelených úloh',
    'Only for tasks assigned to the current user' => 'Len úlohy pridelené aktuálnemu používateľovi',
    'My projects' => 'Moje projekty',
    'You are not a member of any project.' => 'Nie ste členom žiadneho projektu.',
    'My subtasks' => 'Moje podúlohy',
    '%d subtasks' => '%d podúloh(y)',
    '%d subtask' => '%d podúloha',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Presun úlohy medzi týmito stĺpcami je povolený len pre úlohy pridelené aktuálnemu používateľovi',
    '[DUPLICATE]' => '[DUPLIKÁT]',
    'DKK - Danish Krona' => 'DKK – Dánska koruna',
    'Remove user from group' => 'Odstrániť používateľa zo skupiny',
    'Assign the task to its creator' => 'Prideliť úlohu jej autorovi',
    'This task was sent by email to "%s" with subject "%s".' => 'Táto úloha bude odoslaná emailom „%s” s predmetom „%s”.',
    'Predefined Email Subjects' => 'Preddefinované predmety emailu',
    'Write one subject by line.' => 'Napíšte jeden predmet na riadok.',
    'Create another link' => 'Vytvoriť ďalší odkaz',
    'BRL - Brazilian Real' => 'BRL – Brazílsky real',
    'Add a new Kanboard task' => 'Pridať novú úlohu Kanboard',
    'Subtask not started' => 'Podúloha nezačatá',
    'Subtask currently in progress' => 'Podúloha v riešení',
    'Subtask completed' => 'Podúloha dokončená',
    'Subtask added successfully.' => 'Podúloha úspešne pridaná.',
    '%d subtasks added successfully.' => '%d podúloh úspešne pridaných.',
    'Enter one subtask by line.' => 'Zadajte jednu podúlohu na riadok.',
    'Predefined Contents' => 'Preddefinovaný obsah',
    'Predefined contents' => 'Preddefinovaný obsah',
    'Predefined Task Description' => 'Preddefinované popisy úloh',
    'Do you really want to remove this template? "%s"' => 'Naozaj chcete odstrániť šablónu: „%s”?',
    'Add predefined task description' => 'Pridaný preddefinovaný popis úlohy',
    'Predefined Task Descriptions' => 'Preddefinované popisy úloh',
    'Template created successfully.' => 'Šablóna úspešne pridaná.',
    'Unable to create this template.' => 'Nemožno vytvoriť šablónu.',
    'Template updated successfully.' => 'Šablóna úspešne aktualizovaná.',
    'Unable to update this template.' => 'Nemožno aktualizovať šablónu.',
    'Template removed successfully.' => 'Šablóna úspešne odstránená.',
    'Unable to remove this template.' => 'Nemožno odstrániť šablónu.',
    'Template for the task description' => 'Šablóna popisu úlohy',
    'The start date is greater than the end date' => 'Dátum začiatku je až po dátume ukončenia',
    'Tags must be separated by a comma' => 'Značky musia byť oddelené čiarkou',
    'Only the task title is required' => 'Len názov úlohy je povinný',
    'Creator Username' => 'Prihl. meno autora',
    'Color Name' => 'Meno farby',
    'Column Name' => 'Meno stĺpca',
    'Swimlane Name' => 'Meno dráhy',
    'Time Estimated' => 'Očakávaný čas',
    'Time Spent' => 'Strávený čas',
    'External Link' => 'Externý odkaz',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Táto vlastnosť zapína kanály iCal, kanály RSS a verejné zobrazenie nástenky.',
    'Stop the timer of all subtasks when moving a task to another column' => 'Zastaviť časovač všetkých podúloh, keď je úloha presunutá do iného stĺpca',
    'Subtask Title' => 'Názov podúlohy',
    'Add a subtask and activate the timer when moving a task to another column' => 'Pridať podúlohu a spustiť časovač, keď je úloha presunutá do iného stĺpca',
    'days' => 'dni',
    'minutes' => 'minúty',
    'seconds' => 'sekundy',
    'Assign automatically a color when preset start date is reached' => 'Automaticky nastaviť farbu, keď nastane prednastavený dátum začiatku',
    'Move the task to another column once a predefined start date is reached' => 'Presunúť úlohu do iného stĺpca, keď nastane prednastavený dátum začiatku',
    'This task is now linked to the task %s with the relation "%s"' => 'Táto úloha je teraz prepojená s úlohou %s so vzťahom „%s”',
    'The link with the relation "%s" to the task %s has been removed' => 'Odkaz so vzťahom „%s” na úlohu %s bol odstránený',
    'Custom Filter:' => 'Vlastný filter:',
    'Unable to find this group.' => 'Nemožno nájsť túto skupinu.',
    '%s moved the task #%d to the column "%s"' => '%s presunul úlohu #%d do stĺpca „%s”',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s presunul úlohu #%d na pozíciu %d v stĺpci „%s”',
    '%s moved the task #%d to the swimlane "%s"' => '%s presunul úlohu #%d do dráhy „%s”',
    '%sh spent' => '%s h strávené',
    '%sh estimated' => '%s h očakávané',
    'Select All' => 'Vybrať všetky',
    'Unselect All' => 'Zrušiť výber',
    'Apply action' => 'Použiť akciu',
    'Move selected tasks to another column or swimlane' => 'Presunúť zvolené do iného stĺpca',
    'Edit tasks in bulk' => 'Hromadná úprava úloh',
    'Choose the properties that you would like to change for the selected tasks.' => 'Zvoľte vlastnosti, ktoré chcete zmeniť vo všetkých zvolených úlohách.',
    'Configure this project' => 'Nastaviť projekt',
    'Start now' => 'Začať teraz',
    '%s removed a file from the task #%d' => '%s odstránil súbor z úlohy #%d',
    'Attachment removed from task #%d: %s' => 'Príloha odstránená z úlohy #%d: %s',
    'No color' => 'Bez farby',
    'Attachment removed "%s"' => 'Príloha odstránená „%s”',
    '%s removed a file from the task %s' => '%s odstránil súbor z úlohy %s',
    'Move the task to another swimlane when assigned to a user' => 'Presunúť úlohu do inej dráhy, keď je pridelená používateľovi',
    'Destination swimlane' => 'Cieľová dráha',
    'Assign a category when the task is moved to a specific swimlane' => 'Nastaviť kategóriu, keď je úloha presunutá do zadanej dráhy',
    'Move the task to another swimlane when the category is changed' => 'Presunúť úlohu do inej dráhy, keď je zmenená kategória',
    'Reorder this column by priority (ASC)' => 'Zoradiť stĺpec podľa priority (VZOST)',
    'Reorder this column by priority (DESC)' => 'Zoradiť stĺpec podľa priority (ZOST)',
    'Reorder this column by assignee and priority (ASC)' => 'Zoradiť stĺpec podľa pridelenia a priority (VZOST)',
    'Reorder this column by assignee and priority (DESC)' => 'Zoradiť stĺpec podľa pridelenia a priority (ZOST)',
    'Reorder this column by assignee (A-Z)' => 'Zoradiť stĺpec podľa pridelenia (A-Z)',
    'Reorder this column by assignee (Z-A)' => 'Zoradiť stĺpec podľa pridelenia (Z-A)',
    'Reorder this column by due date (ASC)' => 'Zoradiť stĺpec podľa termínu ukončenia (VZOST)',
    'Reorder this column by due date (DESC)' => 'Zoradiť stĺpec podľa termínu ukončenia (ZOST)',
    'Reorder this column by id (ASC)' => 'Zoradiť tento stĺpec podľa ID (vzostupne)',
    'Reorder this column by id (DESC)' => 'Zoradiť tento stĺpec podľa ID (zostupne)',
    '%s moved the task #%d "%s" to the project "%s"' => '%s presunul/a úlohu č. %d „%s” do projektu „%s”',
    'Task #%d "%s" has been moved to the project "%s"' => 'Úloha č. %d „%s” bola presunutá do projektu „%s”',
    'Move the task to another column when the due date is less than a certain number of days' => 'Presunúť úlohu do iného stĺpca, keď je do termínu ukončenia menej ako zadaný počet dní',
    'Automatically update the start date when the task is moved away from a specific column' => 'Automaticky aktualizovať dátum začiatku, keď je úloha presunutá zo zadaného stĺpca',
    'HTTP Client:' => 'Klient HTTP',
    'Assigned' => 'Priadené',
    'Task limits apply to each swimlane individually' => 'Limit úloh použiť na každú dráhu samostatne',
    'Column task limits apply to each swimlane individually' => 'Limit úloh stĺpca použiť na každú dráhu samostatne',
    'Column task limits are applied to each swimlane individually' => 'Limit úloh stĺpca je použitý na každú dráhu samostatne',
    'Column task limits are applied across swimlanes' => 'Limit úloh stĺpca je použitý na všetky dráhy spolu',
    'Task limit: ' => 'Limit úloh',
    'Change to global tag' => 'Zmeniť globálnu značku',
    'Do you really want to make the tag "%s" global?' => 'Naozaj má byť značka „%s” globálna?',
    'Enable global tags for this project' => 'Zapnúť globálne značky v tomto projekte',
    'Group membership(s):' => 'Členstvo v skupine(ách)',
    '%s is a member of the following group(s): %s' => '%s je členom tejto skupiny(n): %s',
    '%d/%d group(s) shown' => 'zobrazených %d/%d skupíny(ín)',
    'Subtask creation or modification' => 'Vytvorenie alebo úprava podúlohy',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Prideliť úlohu zadanému používateľovi, keď je úloha presunutá do zadanej dráhy',
    'Comment' => 'Komentár',
    'Collapse vertically' => 'Zbaliť vertikálne',
    'Expand vertically' => 'Rozbaliť vertikálne',
    'MXN - Mexican Peso' => 'Mexické peso',
    'Estimated vs actual time per column' => 'Očakávaný a aktuálny čas na stĺpec',
    'HUF - Hungarian Forint' => 'HUF – Maďarský forint',
    'XBT - Bitcoin' => 'XBT – Bitcoin',
    'You must select a file to upload as your avatar!' => 'Musíte zvoliť súbor na nahratie ako svoj avatar',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'nahraný súbor nie je paltný obrázok! (Povolené sú len *.gif, *.jpg, *.jpeg a *.png!)',
    'Automatically set the due date when the task is moved away from a specific column' => 'Automaticky nastaviť termín úlohy po presunutí z určitého stĺpca',
    'No other projects found.' => 'Nenašli sa žiadne ďalšie projekty.',
    'Tasks copied successfully.' => 'Úlohy boli úspešne skopírované.',
    'Unable to copy tasks.' => 'Úlohy sa nepodarilo skopírovať.',
    'Theme' => 'Téma',
    'Theme:' => 'Téma:',
    'Light theme' => 'Svetlá téma',
    'Dark theme' => 'Tmavá téma',
    'Automatic theme - Sync with system' => 'Automatická téma – synchronizácia so systémom',
    'Application managers or more' => 'Správcovia aplikácie alebo vyššie',
    'Administrators' => 'Administrátori',
    'Visibility:' => 'Viditeľnosť:',
    'Standard users' => 'Štandardní používatelia',
    'Visibility is required' => 'Viditeľnosť je povinná',
    'The visibility should be an app role' => 'Viditeľnosť musí byť rolou v aplikácii',
    'Reply' => 'Odpovedať',
    '%s wrote: ' => '%s napísal(a): ',
    'Number of visible tasks in this column and swimlane' => 'Počet viditeľných úloh v tomto stĺpci a plaveckom pruhu',
    'Number of tasks in this swimlane' => 'Počet úloh v tomto plaveckom pruhu',
    'Unable to find another subtask in progress, you can close this window.' => 'Nepodarilo sa nájsť ďalšiu podúlohu v priebehu, môžete zavrieť toto okno.',
    'This theme is invalid' => 'Táto téma je neplatná',
    'This role is invalid' => 'Táto rola je neplatná',
    'This timezone is invalid' => 'Toto časové pásmo je neplatné',
    'This language is invalid' => 'Tento jazyk je neplatný',
    'This URL is invalid' => 'Tento URL je neplatný',
    'Date format invalid' => 'Neplatný formát dátumu',
    'Time format invalid' => 'Neplatný formát času',
    'Invalid Mail transport' => 'Neplatný spôsob odosielania e-mailov',
    'Color invalid' => 'Neplatná farba',
    'This value must be greater or equal to %d' => 'Táto hodnota musí byť väčšia alebo rovná %d',
    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Pridať BOM na začiatok súboru (vyžaduje Microsoft Excel)',
    'Just add these tag(s)' => 'Len pridajte tieto značky',
    'Remove internal link(s)' => 'Odstrániť interné odkazy',
    'Import tasks from another project' => 'Importovať úlohy z iného projektu',
    'Select the project to copy tasks from' => 'Vyberte projekt, z ktorého chcete kopírovať úlohy',
    'The total maximum allowed attachments size is %sB.' => 'Celková maximálna povolená veľkosť príloh je %sB.',
    'Add attachments' => 'Pridať prílohy',
    'Task #%d "%s" is overdue' => 'Úloha #%d „%s” je po termíne',
    'Enable notifications by default for all new users' => 'Predvolene zapnúť upozornenia pre všetkých nových používateľov',
    'Assign the task to its creator for specific columns if no assignee is set manually' => 'Priradiť úlohu jej tvorcovi pre vybrané stĺpce, ak nie je ručne nastavený riešiteľ',
    'Assign a task to the logged user on column change to specified column if no user is assigned' => 'Priradiť úlohu prihlásenému používateľovi pri presune do zadaného stĺpca, ak nie je priradený žiadny používateľ',
];
